Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AllowPolicyExplanation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Details about how the relevant IAM allow policies affect the final access state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3AllowPolicyExplanation

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3AllowPolicyExplanation.



237
238
239
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_access_stateString

Indicates whether the principal has the specified permission for the specified resource, based on evaluating all applicable IAM allow policies. Corresponds to the JSON property allowAccessState

Returns:

  • (String)


219
220
221
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 219

def allow_access_state
  @allow_access_state
end

#explained_policiesArray<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedAllowPolicy>

List of IAM allow policies that were evaluated to check the principal's permissions, with annotations to indicate how each policy contributed to the final result. The list of policies includes the policy for the resource itself, as well as allow policies that are inherited from higher levels of the resource hierarchy, including the organization, the folder, and the project. To learn more about the resource hierarchy, see https://cloud.google.com/iam/ help/resource-hierarchy. Corresponds to the JSON property explainedPolicies



230
231
232
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 230

def explained_policies
  @explained_policies
end

#relevanceString

The relevance of the allow policy type to the overall access state. Corresponds to the JSON property relevance

Returns:

  • (String)


235
236
237
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 235

def relevance
  @relevance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



242
243
244
245
246
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 242

def update!(**args)
  @allow_access_state = args[:allow_access_state] if args.key?(:allow_access_state)
  @explained_policies = args[:explained_policies] if args.key?(:explained_policies)
  @relevance = args[:relevance] if args.key?(:relevance)
end