Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

A tag that applies to a resource during policy evaluation. Tags can be either directly bound to a resource or inherited from its ancestor. EffectiveTag contains the name and namespaced_name of the tag value and tag key, with additional fields of inherited to indicate the inheritance status of the effective tag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag.



343
344
345
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inheritedBoolean Also known as: inherited?

Output only. Indicates the inheritance status of a tag value attached to the given resource. If the tag value is inherited from one of the resource's ancestors, inherited will be true. If false, then the tag value is directly attached to the resource, inherited will be false. Corresponds to the JSON property inherited

Returns:

  • (Boolean)


308
309
310
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 308

def inherited
  @inherited
end

#namespaced_tag_keyString

Output only. The namespaced name of the TagKey. Can be in the form organization_id`/`tag_key_short_name or project_id`/`tag_key_short_name or project_number`/`tag_key_short_name. Corresponds to the JSON property namespacedTagKey

Returns:

  • (String)


316
317
318
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 316

def namespaced_tag_key
  @namespaced_tag_key
end

#namespaced_tag_valueString

Output only. The namespaced name of the TagValue. Can be in the form organization_id`/`tag_key_short_name`/`tag_value_short_name or project_id`/ `tag_key_short_name`/`tag_value_short_name or project_number`/` tag_key_short_name`/`tag_value_short_name. Corresponds to the JSON property namespacedTagValue

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 324

def namespaced_tag_value
  @namespaced_tag_value
end

#tag_keyString

Output only. The name of the TagKey, in the format tagKeys/id`, such as tagKeys/123. Corresponds to the JSON propertytagKey`

Returns:

  • (String)


330
331
332
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 330

def tag_key
  @tag_key
end

#tag_key_parent_nameString

The parent name of the tag key. Must be in the format organizations/ organization_idor `projects/`project_number Corresponds to the JSON property tagKeyParentName

Returns:

  • (String)


336
337
338
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 336

def tag_key_parent_name
  @tag_key_parent_name
end

#tag_valueString

Output only. Resource name for TagValue in the format tagValues/456. Corresponds to the JSON property tagValue

Returns:

  • (String)


341
342
343
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 341

def tag_value
  @tag_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



348
349
350
351
352
353
354
355
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 348

def update!(**args)
  @inherited = args[:inherited] if args.key?(:inherited)
  @namespaced_tag_key = args[:namespaced_tag_key] if args.key?(:namespaced_tag_key)
  @namespaced_tag_value = args[:namespaced_tag_value] if args.key?(:namespaced_tag_value)
  @tag_key = args[:tag_key] if args.key?(:tag_key)
  @tag_key_parent_name = args[:tag_key_parent_name] if args.key?(:tag_key_parent_name)
  @tag_value = args[:tag_value] if args.key?(:tag_value)
end