Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

This message defines attributes for a node that handles a network request. The node can be either a service or an application that sends, forwards, or receives the request. Service peers should fill in principal and labels as appropriate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer.



375
376
377
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ipString

The IPv4 or IPv6 address of the peer. Corresponds to the JSON property ip

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 368

def ip
  @ip
end

#portFixnum

The network port of the peer. Corresponds to the JSON property port

Returns:

  • (Fixnum)


373
374
375
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 373

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



380
381
382
383
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 380

def update!(**args)
  @ip = args[:ip] if args.key?(:ip)
  @port = args[:port] if args.key?(:port)
end