Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

This message defines attributes for an HTTP request. If the actual request is not an HTTP request, the runtime system should try to map the actual request to an equivalent HTTP request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest.



398
399
400
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#receive_timeString

Optional. The timestamp when the destination service receives the first byte of the request. Corresponds to the JSON property receiveTime

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 396

def receive_time
  @receive_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



403
404
405
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 403

def update!(**args)
  @receive_time = args[:receive_time] if args.key?(:receive_time)
end