Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Core attributes for a resource. A resource is an addressable (named) entity provided by the destination service. For example, a Compute Engine instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContextResource

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContextResource.



437
438
439
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The stable identifier (name) of a resource on the service. A resource can be logically identified as //resource.service/resource.name`. Unlike the resource URI, the resource name doesn't contain any protocol and version information. For a list of full resource name formats, see https://cloud. google.com/iam/help/troubleshooter/full-resource-names Corresponds to the JSON propertyname`

Returns:

  • (String)


420
421
422
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 420

def name
  @name
end

#serviceString

The name of the service that this resource belongs to, such as compute. googleapis.com. The service name might not match the DNS hostname that actually serves the request. For a full list of resource service values, see https://cloud.google.com/iam/help/conditions/resource-services Corresponds to the JSON property service

Returns:

  • (String)


428
429
430
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 428

def service
  @service
end

#typeString

The type of the resource, in the format service`/`kind. For a full list of resource type values, see https://cloud.google.com/iam/help/conditions/ resource-types Corresponds to the JSON property type

Returns:

  • (String)


435
436
437
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 435

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



442
443
444
445
446
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 442

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end