Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedDenyPrincipalMatching

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Details about whether the principal in the request is listed as a denied principal in the deny rule, either directly or through membership in a principal set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedDenyPrincipalMatching

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedDenyPrincipalMatching.



708
709
710
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipString

Indicates whether the principal is listed as a denied principal in the deny rule, either directly or through membership in a principal set. Corresponds to the JSON property membership

Returns:

  • (String)


700
701
702
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 700

def membership
  @membership
end

#relevanceString

The relevance of the principal's status to the overall determination for the role binding. Corresponds to the JSON property relevance

Returns:

  • (String)


706
707
708
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 706

def relevance
  @relevance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



713
714
715
716
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 713

def update!(**args)
  @membership = args[:membership] if args.key?(:membership)
  @relevance = args[:relevance] if args.key?(:relevance)
end