Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Details about whether the permission in the request is denied by the deny rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching.



734
735
736
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#permission_matching_stateString

Indicates whether the permission in the request is denied by the deny rule. Corresponds to the JSON property permissionMatchingState

Returns:

  • (String)


726
727
728
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 726

def permission_matching_state
  @permission_matching_state
end

#relevanceString

The relevance of the permission status to the overall determination for the rule. Corresponds to the JSON property relevance

Returns:

  • (String)


732
733
734
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 732

def relevance
  @relevance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



739
740
741
742
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 739

def update!(**args)
  @permission_matching_state = args[:permission_matching_state] if args.key?(:permission_matching_state)
  @relevance = args[:relevance] if args.key?(:relevance)
end