Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Details about how a specific IAM deny policy Policy contributed to the access check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy.



864
865
866
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deny_access_stateString

Required. Indicates whether this policy denies the specified permission to the specified principal for the specified resource. This field does not indicate whether the principal actually has the permission for the resource. There might be another policy that overrides this policy. To determine whether the principal actually has the permission, use the overall_access_state field in the TroubleshootIamPolicyResponse. Corresponds to the JSON property denyAccessState

Returns:

  • (String)


842
843
844
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 842

def deny_access_state
  @deny_access_state
end

#policyGoogle::Apis::PolicytroubleshooterV3::GoogleIamV2Policy

Data for an IAM policy. Corresponds to the JSON property policy



847
848
849
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 847

def policy
  @policy
end

#relevanceString

The relevance of this policy to the overall access state in the TroubleshootIamPolicyResponse. If the sender of the request does not have access to the policy, this field is omitted. Corresponds to the JSON property relevance

Returns:

  • (String)


854
855
856
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 854

def relevance
  @relevance
end

#rule_explanationsArray<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanation>

Details about how each rule in the policy affects the principal's inability to use the permission for the resource. The order of the deny rule matches the order of the rules in the deny policy. If the sender of the request does not have access to the policy, this field is omitted. Corresponds to the JSON property ruleExplanations



862
863
864
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 862

def rule_explanations
  @rule_explanations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



869
870
871
872
873
874
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 869

def update!(**args)
  @deny_access_state = args[:deny_access_state] if args.key?(:deny_access_state)
  @policy = args[:policy] if args.key?(:policy)
  @relevance = args[:relevance] if args.key?(:relevance)
  @rule_explanations = args[:rule_explanations] if args.key?(:rule_explanations)
end