Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Request for TroubleshootIamPolicy.
Instance Attribute Summary collapse
-
#access_tuple ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AccessTuple
Information about the principal, resource, and permission to check.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest.
937 938 939 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_tuple ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AccessTuple
Information about the principal, resource, and permission to check.
Corresponds to the JSON property accessTuple
935 936 937 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 935 def access_tuple @access_tuple end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
942 943 944 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 942 def update!(**args) @access_tuple = args[:access_tuple] if args.key?(:access_tuple) end |