Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb

Overview

Response for TroubleshootIamPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyResponse

Returns a new instance of GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyResponse.



973
974
975
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tupleGoogle::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AccessTuple

Information about the principal, resource, and permission to check. Corresponds to the JSON property accessTuple



954
955
956
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 954

def access_tuple
  @access_tuple
end

#allow_policy_explanationGoogle::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AllowPolicyExplanation

Details about how the relevant IAM allow policies affect the final access state. Corresponds to the JSON property allowPolicyExplanation



960
961
962
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 960

def allow_policy_explanation
  @allow_policy_explanation
end

#deny_policy_explanationGoogle::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation

Details about how the relevant IAM deny policies affect the final access state. Corresponds to the JSON property denyPolicyExplanation



965
966
967
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 965

def deny_policy_explanation
  @deny_policy_explanation
end

#overall_access_stateString

Indicates whether the principal has the specified permission for the specified resource, based on evaluating all types of the applicable IAM policies. Corresponds to the JSON property overallAccessState

Returns:

  • (String)


971
972
973
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 971

def overall_access_state
  @overall_access_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



978
979
980
981
982
983
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 978

def update!(**args)
  @access_tuple = args[:access_tuple] if args.key?(:access_tuple)
  @allow_policy_explanation = args[:allow_policy_explanation] if args.key?(:allow_policy_explanation)
  @deny_policy_explanation = args[:deny_policy_explanation] if args.key?(:deny_policy_explanation)
  @overall_access_state = args[:overall_access_state] if args.key?(:overall_access_state)
end