Module: Google::Apis::PolicytroubleshooterV3
- Defined in:
- lib/google/apis/policytroubleshooter_v3.rb,
lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/service.rb,
lib/google/apis/policytroubleshooter_v3/gem_version.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Policy Troubleshooter API
Defined Under Namespace
Classes: GoogleCloudPolicytroubleshooterIamV3AccessTuple, GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanation, GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership, GoogleCloudPolicytroubleshooterIamV3AllowPolicyExplanation, GoogleCloudPolicytroubleshooterIamV3ConditionContext, GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag, GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer, GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest, GoogleCloudPolicytroubleshooterIamV3ConditionContextResource, GoogleCloudPolicytroubleshooterIamV3ConditionExplanation, GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState, GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation, GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanation, GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedDenyPrincipalMatching, GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching, GoogleCloudPolicytroubleshooterIamV3ExplainedAllowPolicy, GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy, GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource, GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyRequest, GoogleCloudPolicytroubleshooterIamV3TroubleshootIamPolicyResponse, GoogleIamV1AuditConfig, GoogleIamV1AuditLogConfig, GoogleIamV1Binding, GoogleIamV1Policy, GoogleIamV2DenyRule, GoogleIamV2Policy, GoogleIamV2PolicyRule, GoogleRpcStatus, GoogleTypeExpr, PolicyTroubleshooterService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-policytroubleshooter_v3 gem
"0.2.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260111"- VERSION =
Version of the Policy Troubleshooter API this client connects to. This is NOT the gem version.
'V3'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'