Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AccessTuple
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AccessTuple
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Information about the principal, resource, and permission to check.
Instance Attribute Summary collapse
-
#condition_context ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContext
Additional context for troubleshooting conditional role bindings and deny rules.
-
#full_resource_name ⇒ String
Required.
-
#permission ⇒ String
Required.
-
#permission_fqdn ⇒ String
Output only.
-
#principal ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3AccessTuple
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3AccessTuple.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3AccessTuple
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3AccessTuple.
68 69 70 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 68 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition_context ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContext
Additional context for troubleshooting conditional role bindings and deny
rules.
Corresponds to the JSON property conditionContext
33 34 35 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 33 def condition_context @condition_context end |
#full_resource_name ⇒ String
Required. The full resource name that identifies the resource. For example, //
compute.googleapis.com/projects/my-project/zones/us-central1-a/instances/my-
instance. For examples of full resource names for Google Cloud services, see
https://cloud.google.com/iam/help/troubleshooter/full-resource-names.
Corresponds to the JSON property fullResourceName
41 42 43 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 41 def full_resource_name @full_resource_name end |
#permission ⇒ String
Required. The IAM permission to check for, either in the v1 permission
format or the v2 permission format. For a complete list of IAM permissions
in the v1 format, see https://cloud.google.com/iam/help/permissions/
reference. For a list of IAM permissions in the v2 format, see https://cloud.
google.com/iam/help/deny/supported-permissions. For a complete list of
predefined IAM roles and the permissions in each role, see https://cloud.
google.com/iam/help/roles/reference.
Corresponds to the JSON property permission
52 53 54 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 52 def @permission end |
#permission_fqdn ⇒ String
Output only. The permission that Policy Troubleshooter checked for, in the v2
format.
Corresponds to the JSON property permissionFqdn
58 59 60 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 58 def @permission_fqdn end |
#principal ⇒ String
Required. The email address of the principal whose access you want to check.
For example, alice@example.com or my-service-account@my-project.iam.
gserviceaccount.com. The principal must be a Google Account or a service
account. Other types of principals are not supported.
Corresponds to the JSON property principal
66 67 68 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 66 def principal @principal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73 74 75 76 77 78 79 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 73 def update!(**args) @condition_context = args[:condition_context] if args.key?(:condition_context) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @permission = args[:permission] if args.key?(:permission) @permission_fqdn = args[:permission_fqdn] if args.key?(:permission_fqdn) @principal = args[:principal] if args.key?(:principal) end |