Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Details about whether the role binding includes the principal.
Instance Attribute Summary collapse
-
#membership ⇒ String
Indicates whether the role binding includes the principal.
-
#relevance ⇒ String
The relevance of the principal's status to the overall determination for the role binding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3AllowBindingExplanationAnnotatedAllowMembership.
199 200 201 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership ⇒ String
Indicates whether the role binding includes the principal.
Corresponds to the JSON property membership
191 192 193 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 191 def membership @membership end |
#relevance ⇒ String
The relevance of the principal's status to the overall determination for the
role binding.
Corresponds to the JSON property relevance
197 198 199 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 197 def relevance @relevance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
204 205 206 207 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 204 def update!(**args) @membership = args[:membership] if args.key?(:membership) @relevance = args[:relevance] if args.key?(:relevance) end |