Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContext
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Additional context for troubleshooting conditional role bindings and deny rules.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer
This message defines attributes for a node that handles a network request.
-
#effective_tags ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag>
Output only.
-
#request ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest
This message defines attributes for an HTTP request.
-
#resource ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextResource
Core attributes for a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContext
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionContext
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionContext.
281 282 283 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextPeer
This message defines attributes for a node that handles a network request. The
node can be either a service or an application that sends, forwards, or
receives the request. Service peers should fill in principal and labels as
appropriate.
Corresponds to the JSON property destination
260 261 262 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 260 def destination @destination end |
#effective_tags ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextEffectiveTag>
Output only. The effective tags on the resource. The effective tags are
fetched during troubleshooting.
Corresponds to the JSON property effectiveTags
266 267 268 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 266 def @effective_tags end |
#request ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextRequest
This message defines attributes for an HTTP request. If the actual request is
not an HTTP request, the runtime system should try to map the actual request
to an equivalent HTTP request.
Corresponds to the JSON property request
273 274 275 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 273 def request @request end |
#resource ⇒ Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionContextResource
Core attributes for a resource. A resource is an addressable (named) entity
provided by the destination service. For example, a Compute Engine instance.
Corresponds to the JSON property resource
279 280 281 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 279 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
286 287 288 289 290 291 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 286 def update!(**args) @destination = args[:destination] if args.key?(:destination) @effective_tags = args[:effective_tags] if args.key?(:effective_tags) @request = args[:request] if args.key?(:request) @resource = args[:resource] if args.key?(:resource) end |