Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanation
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Explanation for how a condition affects a principal's access
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleRpcStatus>
Any errors that prevented complete evaluation of the condition expression.
-
#evaluation_states ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState>
The value of each statement of the condition expression.
-
#value ⇒ Object
Value of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionExplanation
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3ConditionExplanation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionExplanation
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionExplanation.
470 471 472 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleRpcStatus>
Any errors that prevented complete evaluation of the condition expression.
Corresponds to the JSON property errors
456 457 458 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 456 def errors @errors end |
#evaluation_states ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState>
The value of each statement of the condition expression. The value can be
true, false, or null. The value is null if the statement can't be
evaluated.
Corresponds to the JSON property evaluationStates
463 464 465 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 463 def evaluation_states @evaluation_states end |
#value ⇒ Object
Value of the condition.
Corresponds to the JSON property value
468 469 470 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 468 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
475 476 477 478 479 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 475 def update!(**args) @errors = args[:errors] if args.key?(:errors) @evaluation_states = args[:evaluation_states] if args.key?(:evaluation_states) @value = args[:value] if args.key?(:value) end |