Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Evaluated state of a condition expression.
Instance Attribute Summary collapse
-
#end ⇒ Fixnum
End position of an expression in the condition, by character, end included, for example: the end position of the first part of
a==b || c==dwould be 4. -
#errors ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleRpcStatus>
Any errors that prevented complete evaluation of the condition expression.
-
#start ⇒ Fixnum
Start position of an expression in the condition, by character.
-
#value ⇒ Object
Value of this expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ConditionExplanationEvaluationState.
507 508 509 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Fixnum
End position of an expression in the condition, by character, end included,
for example: the end position of the first part of a==b || c==d would be 4.
Corresponds to the JSON property end
490 491 492 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 490 def end @end end |
#errors ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleRpcStatus>
Any errors that prevented complete evaluation of the condition expression.
Corresponds to the JSON property errors
495 496 497 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 495 def errors @errors end |
#start ⇒ Fixnum
Start position of an expression in the condition, by character.
Corresponds to the JSON property start
500 501 502 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 500 def start @start end |
#value ⇒ Object
Value of this expression.
Corresponds to the JSON property value
505 506 507 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 505 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
512 513 514 515 516 517 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 512 def update!(**args) @end = args[:end] if args.key?(:end) @errors = args[:errors] if args.key?(:errors) @start = args[:start] if args.key?(:start) @value = args[:value] if args.key?(:value) end |