Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Details about how the relevant IAM deny policies affect the final access state.
Instance Attribute Summary collapse
-
#deny_access_state ⇒ String
Indicates whether the principal is denied the specified permission for the specified resource, based on evaluating all applicable IAM deny policies.
-
#explained_resources ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource>
List of resources with IAM deny policies that were evaluated to check the principal's denied permissions, with annotations to indicate how each policy contributed to the final result.
-
#permission_deniable ⇒ Boolean
(also: #permission_deniable?)
Indicates whether the permission to troubleshoot is supported in deny policies.
-
#relevance ⇒ String
The relevance of the deny policy result to the overall access state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3DenyPolicyExplanation.
553 554 555 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deny_access_state ⇒ String
Indicates whether the principal is denied the specified permission for the
specified resource, based on evaluating all applicable IAM deny policies.
Corresponds to the JSON property denyAccessState
528 529 530 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 528 def deny_access_state @deny_access_state end |
#explained_resources ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource>
List of resources with IAM deny policies that were evaluated to check the
principal's denied permissions, with annotations to indicate how each policy
contributed to the final result. The list of resources includes the policy for
the resource itself, as well as policies that are inherited from higher levels
of the resource hierarchy, including the organization, the folder, and the
project. The order of the resources starts from the resource and climbs up the
resource hierarchy. To learn more about the resource hierarchy, see https://
cloud.google.com/iam/help/resource-hierarchy.
Corresponds to the JSON property explainedResources
540 541 542 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 540 def explained_resources @explained_resources end |
#permission_deniable ⇒ Boolean Also known as: permission_deniable?
Indicates whether the permission to troubleshoot is supported in deny policies.
Corresponds to the JSON property permissionDeniable
545 546 547 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 545 def @permission_deniable end |
#relevance ⇒ String
The relevance of the deny policy result to the overall access state.
Corresponds to the JSON property relevance
551 552 553 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 551 def relevance @relevance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
558 559 560 561 562 563 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 558 def update!(**args) @deny_access_state = args[:deny_access_state] if args.key?(:deny_access_state) @explained_resources = args[:explained_resources] if args.key?(:explained_resources) @permission_deniable = args[:permission_deniable] if args.key?(:permission_deniable) @relevance = args[:relevance] if args.key?(:relevance) end |