Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Details about whether the permission in the request is denied by the deny rule.
Instance Attribute Summary collapse
-
#permission_matching_state ⇒ String
Indicates whether the permission in the request is denied by the deny rule.
-
#relevance ⇒ String
The relevance of the permission status to the overall determination for the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3DenyRuleExplanationAnnotatedPermissionMatching.
734 735 736 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#permission_matching_state ⇒ String
Indicates whether the permission in the request is denied by the deny rule.
Corresponds to the JSON property permissionMatchingState
726 727 728 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 726 def @permission_matching_state end |
#relevance ⇒ String
The relevance of the permission status to the overall determination for the
rule.
Corresponds to the JSON property relevance
732 733 734 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 732 def relevance @relevance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
739 740 741 742 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 739 def update!(**args) @permission_matching_state = args[:permission_matching_state] if args.key?(:permission_matching_state) @relevance = args[:relevance] if args.key?(:relevance) end |