Class: Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource
- Inherits:
-
Object
- Object
- Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policytroubleshooter_v3/classes.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb,
lib/google/apis/policytroubleshooter_v3/representations.rb
Overview
Details about how a specific resource contributed to the deny policy evaluation.
Instance Attribute Summary collapse
-
#deny_access_state ⇒ String
Required.
-
#explained_policies ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy>
List of IAM deny policies that were evaluated to check the principal's denied permissions, with annotations to indicate how each policy contributed to the final result.
-
#full_resource_name ⇒ String
The full resource name that identifies the resource.
-
#relevance ⇒ String
The relevance of this policy to the overall access state in the TroubleshootIamPolicyResponse.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource
constructor
A new instance of GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource
Returns a new instance of GoogleCloudPolicytroubleshooterIamV3ExplainedDenyResource.
915 916 917 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deny_access_state ⇒ String
Required. Indicates whether any policies attached to this resource deny the
specific permission to the specified principal for the specified resource.
This field does not indicate whether the principal actually has the
permission for the resource. There might be another policy that overrides this
policy. To determine whether the principal actually has the permission, use
the overall_access_state field in the TroubleshootIamPolicyResponse.
Corresponds to the JSON property denyAccessState
890 891 892 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 890 def deny_access_state @deny_access_state end |
#explained_policies ⇒ Array<Google::Apis::PolicytroubleshooterV3::GoogleCloudPolicytroubleshooterIamV3ExplainedDenyPolicy>
List of IAM deny policies that were evaluated to check the principal's denied
permissions, with annotations to indicate how each policy contributed to the
final result.
Corresponds to the JSON property explainedPolicies
897 898 899 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 897 def explained_policies @explained_policies end |
#full_resource_name ⇒ String
The full resource name that identifies the resource. For example, //compute.
googleapis.com/projects/my-project/zones/us-central1-a/instances/my-instance.
If the sender of the request does not have access to the policy, this field is
omitted. For examples of full resource names for Google Cloud services, see
https://cloud.google.com/iam/help/troubleshooter/full-resource-names.
Corresponds to the JSON property fullResourceName
906 907 908 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 906 def full_resource_name @full_resource_name end |
#relevance ⇒ String
The relevance of this policy to the overall access state in the
TroubleshootIamPolicyResponse. If the sender of the request does not have
access to the policy, this field is omitted.
Corresponds to the JSON property relevance
913 914 915 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 913 def relevance @relevance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
920 921 922 923 924 925 |
# File 'lib/google/apis/policytroubleshooter_v3/classes.rb', line 920 def update!(**args) @deny_access_state = args[:deny_access_state] if args.key?(:deny_access_state) @explained_policies = args[:explained_policies] if args.key?(:explained_policies) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @relevance = args[:relevance] if args.key?(:relevance) end |